@@ -27,13 +27,13 @@
 static uint64_t tick_sources(uint64_t cur_time, uint64_t last_time)
 {
 	struct obs_core_data *data = &obs->data;
-	struct obs_source    *source;
-	uint64_t             delta_time;
-	float                seconds;
+	struct obs_source *source;
+	uint64_t delta_time;
+	float seconds;
 
 	if (!last_time)
 		last_time = cur_time -
-			video_output_get_frame_time(obs->video.video);
+			    video_output_get_frame_time(obs->video.video);
 
 	delta_time = cur_time - last_time;
 	seconds = (float)((double)delta_time / 1000000000.0);
@@ -59,7 +59,7 @@ static uint64_t tick_sources(uint64_t cur_time, uint64_t last_time)
 	source = data->first_source;
 	while (source) {
 		struct obs_source *cur_source = obs_source_get_ref(source);
-		source = (struct obs_source*)source->context.next;
+		source = (struct obs_source *)source->context.next;
 
 		if (cur_source) {
 			obs_source_video_tick(cur_source, seconds);
@@ -109,24 +109,25 @@ static inline void set_render_size(uint32_t width, uint32_t height)
 
 static inline void unmap_last_surface(struct obs_core_video *video)
 {
-	if (video->mapped_surface) {
-		gs_stagesurface_unmap(video->mapped_surface);
-		video->mapped_surface = NULL;
+	for (int c = 0; c < NUM_CHANNELS; ++c) {
+		if (video->mapped_surfaces[c]) {
+			gs_stagesurface_unmap(video->mapped_surfaces[c]);
+			video->mapped_surfaces[c] = NULL;
+		}
 	}
 }
 
 static const char *render_main_texture_name = "render_main_texture";
-static inline void render_main_texture(struct obs_core_video *video,
-		int cur_texture)
+static inline void render_main_texture(struct obs_core_video *video)
 {
 	profile_start(render_main_texture_name);
 	GS_DEBUG_MARKER_BEGIN(GS_DEBUG_COLOR_MAIN_TEXTURE,
-			render_main_texture_name);
+			      render_main_texture_name);
 
 	struct vec4 clear_color;
 	vec4_set(&clear_color, 0.0f, 0.0f, 0.0f, 0.0f);
 
-	gs_set_render_target(video->render_textures[cur_texture], NULL);
+	gs_set_render_target(video->render_texture, NULL);
 	gs_clear(GS_CLEAR_COLOR, &clear_color, 1.0f, 0);
 
 	set_render_size(video->base_width, video->base_height);
@@ -137,34 +138,38 @@ static inline void render_main_texture(struct obs_core_video *video,
 		struct draw_callback *callback;
 		callback = obs->data.draw_callbacks.array + (i - 1);
 
-		callback->draw(callback->param,
-				video->base_width, video->base_height);
+		callback->draw(callback->param, video->base_width,
+			       video->base_height);
 	}
 
 	pthread_mutex_unlock(&obs->data.draw_callbacks_mutex);
 
 	obs_view_render(&obs->data.main_view);
 
-	video->textures_rendered[cur_texture] = true;
+	video->texture_rendered = true;
 
 	GS_DEBUG_MARKER_END();
 	profile_end(render_main_texture_name);
 }
 
-static inline gs_effect_t *get_scale_effect_internal(
-		struct obs_core_video *video)
+static inline gs_effect_t *
+get_scale_effect_internal(struct obs_core_video *video)
 {
 	/* if the dimension is under half the size of the original image,
 	 * bicubic/lanczos can't sample enough pixels to create an accurate
 	 * image, so use the bilinear low resolution effect instead */
-	if (video->output_width  < (video->base_width  / 2) &&
+	if (video->output_width < (video->base_width / 2) &&
 	    video->output_height < (video->base_height / 2)) {
 		return video->bilinear_lowres_effect;
 	}
 
 	switch (video->scale_type) {
-	case OBS_SCALE_BILINEAR: return video->default_effect;
-	case OBS_SCALE_LANCZOS:  return video->lanczos_effect;
+	case OBS_SCALE_BILINEAR:
+		return video->default_effect;
+	case OBS_SCALE_LANCZOS:
+		return video->lanczos_effect;
+	case OBS_SCALE_AREA:
+		return video->area_effect;
 	case OBS_SCALE_BICUBIC:
 	default:;
 	}
@@ -173,16 +178,16 @@ static inline gs_effect_t *get_scale_effect_internal(
 }
 
 static inline bool resolution_close(struct obs_core_video *video,
-		uint32_t width, uint32_t height)
+				    uint32_t width, uint32_t height)
 {
-	long width_cmp  = (long)video->base_width  - (long)width;
+	long width_cmp = (long)video->base_width - (long)width;
 	long height_cmp = (long)video->base_height - (long)height;
 
 	return labs(width_cmp) <= 16 && labs(height_cmp) <= 16;
 }
 
 static inline gs_effect_t *get_scale_effect(struct obs_core_video *video,
-		uint32_t width, uint32_t height)
+					    uint32_t width, uint32_t height)
 {
 	if (resolution_close(video, width, height)) {
 		return video->default_effect;
@@ -191,55 +196,61 @@ static inline gs_effect_t *get_scale_effect(struct obs_core_video *video,
 		 * or bilinear by default */
 		gs_effect_t *effect = get_scale_effect_internal(video);
 		if (!effect)
-			effect = !!video->bicubic_effect ?
-				video->bicubic_effect :
-				video->default_effect;
+			effect = !!video->bicubic_effect
+					 ? video->bicubic_effect
+					 : video->default_effect;
 		return effect;
 	}
 }
 
 static const char *render_output_texture_name = "render_output_texture";
-static inline void render_output_texture(struct obs_core_video *video,
-		int cur_texture, int prev_texture)
+static inline gs_texture_t *render_output_texture(struct obs_core_video *video)
 {
-	profile_start(render_output_texture_name);
+	gs_texture_t *texture = video->render_texture;
+	gs_texture_t *target = video->output_texture;
+	uint32_t width = gs_texture_get_width(target);
+	uint32_t height = gs_texture_get_height(target);
 
-	gs_texture_t *texture = video->render_textures[prev_texture];
-	gs_texture_t *target  = video->output_textures[cur_texture];
-	uint32_t     width   = gs_texture_get_width(target);
-	uint32_t     height  = gs_texture_get_height(target);
-	struct vec2  base_i;
-
-	vec2_set(&base_i,
-		1.0f / (float)video->base_width,
-		1.0f / (float)video->base_height);
-
-	gs_effect_t    *effect  = get_scale_effect(video, width, height);
+	gs_effect_t *effect = get_scale_effect(video, width, height);
 	gs_technique_t *tech;
 
 	if (video->ovi.output_format == VIDEO_FORMAT_RGBA) {
 		tech = gs_effect_get_technique(effect, "DrawAlphaDivide");
 	} else {
-		tech = gs_effect_get_technique(effect, "DrawMatrix");
+		if ((effect == video->default_effect) &&
+		    (width == video->base_width) &&
+		    (height == video->base_height))
+			return texture;
+
+		tech = gs_effect_get_technique(effect, "Draw");
 	}
 
-	gs_eparam_t    *image   = gs_effect_get_param_by_name(effect, "image");
-	gs_eparam_t    *matrix  = gs_effect_get_param_by_name(effect,
-			"color_matrix");
-	gs_eparam_t    *bres_i  = gs_effect_get_param_by_name(effect,
-			"base_dimension_i");
-	size_t      passes, i;
+	profile_start(render_output_texture_name);
 
-	if (!video->textures_rendered[prev_texture])
-		goto end;
+	gs_eparam_t *image = gs_effect_get_param_by_name(effect, "image");
+	gs_eparam_t *bres =
+		gs_effect_get_param_by_name(effect, "base_dimension");
+	gs_eparam_t *bres_i =
+		gs_effect_get_param_by_name(effect, "base_dimension_i");
+	size_t passes, i;
 
 	gs_set_render_target(target, NULL);
 	set_render_size(width, height);
 
-	if (bres_i)
+	if (bres) {
+		struct vec2 base;
+		vec2_set(&base, (float)video->base_width,
+			 (float)video->base_height);
+		gs_effect_set_vec2(bres, &base);
+	}
+
+	if (bres_i) {
+		struct vec2 base_i;
+		vec2_set(&base_i, 1.0f / (float)video->base_width,
+			 1.0f / (float)video->base_height);
 		gs_effect_set_vec2(bres_i, &base_i);
+	}
 
-	gs_effect_set_val(matrix, video->color_matrix, sizeof(float) * 16);
 	gs_effect_set_texture(image, texture);
 
 	gs_enable_blending(false);
@@ -252,165 +263,132 @@ static inline void render_output_texture(struct obs_core_video *video,
 	gs_technique_end(tech);
 	gs_enable_blending(true);
 
-	video->textures_output[cur_texture] = true;
-
-end:
 	profile_end(render_output_texture_name);
+
+	return target;
 }
 
-static inline void set_eparam(gs_effect_t *effect, const char *name, float val)
+static void render_convert_plane(gs_effect_t *effect, gs_texture_t *target,
+				 const char *tech_name)
 {
-	gs_eparam_t *param = gs_effect_get_param_by_name(effect, name);
-	gs_effect_set_float(param, val);
+	gs_technique_t *tech = gs_effect_get_technique(effect, tech_name);
+
+	const uint32_t width = gs_texture_get_width(target);
+	const uint32_t height = gs_texture_get_height(target);
+
+	gs_set_render_target(target, NULL);
+	set_render_size(width, height);
+
+	size_t passes = gs_technique_begin(tech);
+	for (size_t i = 0; i < passes; i++) {
+		gs_technique_begin_pass(tech, i);
+		gs_draw(GS_TRIS, 0, 3);
+		gs_technique_end_pass(tech);
+	}
+	gs_technique_end(tech);
 }
 
 static const char *render_convert_texture_name = "render_convert_texture";
 static void render_convert_texture(struct obs_core_video *video,
-		int cur_texture, int prev_texture)
+				   gs_texture_t *texture)
 {
 	profile_start(render_convert_texture_name);
 
-	gs_texture_t *texture = video->output_textures[prev_texture];
-	gs_texture_t *target  = video->convert_textures[cur_texture];
-	float        fwidth  = (float)video->output_width;
-	float        fheight = (float)video->output_height;
-	size_t       passes, i;
+	gs_effect_t *effect = video->conversion_effect;
+	gs_eparam_t *color_vec0 =
+		gs_effect_get_param_by_name(effect, "color_vec0");
+	gs_eparam_t *color_vec1 =
+		gs_effect_get_param_by_name(effect, "color_vec1");
+	gs_eparam_t *color_vec2 =
+		gs_effect_get_param_by_name(effect, "color_vec2");
+	gs_eparam_t *image = gs_effect_get_param_by_name(effect, "image");
+	gs_eparam_t *width_i = gs_effect_get_param_by_name(effect, "width_i");
 
-	gs_effect_t    *effect  = video->conversion_effect;
-	gs_eparam_t    *image   = gs_effect_get_param_by_name(effect, "image");
-	gs_technique_t *tech    = gs_effect_get_technique(effect,
-			video->conversion_tech);
-
-	if (!video->textures_output[prev_texture])
-		goto end;
-
-	set_eparam(effect, "u_plane_offset", (float)video->plane_offsets[1]);
-	set_eparam(effect, "v_plane_offset", (float)video->plane_offsets[2]);
-	set_eparam(effect, "width",  fwidth);
-	set_eparam(effect, "height", fheight);
-	set_eparam(effect, "width_i",  1.0f / fwidth);
-	set_eparam(effect, "height_i", 1.0f / fheight);
-	set_eparam(effect, "width_d2",  fwidth  * 0.5f);
-	set_eparam(effect, "height_d2", fheight * 0.5f);
-	set_eparam(effect, "width_d2_i",  1.0f / (fwidth  * 0.5f));
-	set_eparam(effect, "height_d2_i", 1.0f / (fheight * 0.5f));
-	set_eparam(effect, "input_height", (float)video->conversion_height);
-
-	gs_effect_set_texture(image, texture);
-
-	gs_set_render_target(target, NULL);
-	set_render_size(video->output_width, video->conversion_height);
+	struct vec4 vec0, vec1, vec2;
+	vec4_set(&vec0, video->color_matrix[4], video->color_matrix[5],
+		 video->color_matrix[6], video->color_matrix[7]);
+	vec4_set(&vec1, video->color_matrix[0], video->color_matrix[1],
+		 video->color_matrix[2], video->color_matrix[3]);
+	vec4_set(&vec2, video->color_matrix[8], video->color_matrix[9],
+		 video->color_matrix[10], video->color_matrix[11]);
 
 	gs_enable_blending(false);
-	passes = gs_technique_begin(tech);
-	for (i = 0; i < passes; i++) {
-		gs_technique_begin_pass(tech, i);
-		gs_draw_sprite(texture, 0, video->output_width,
-				video->conversion_height);
-		gs_technique_end_pass(tech);
+
+	if (video->convert_textures[0]) {
+		gs_effect_set_texture(image, texture);
+		gs_effect_set_vec4(color_vec0, &vec0);
+		render_convert_plane(effect, video->convert_textures[0],
+				     video->conversion_techs[0]);
+
+		if (video->convert_textures[1]) {
+			gs_effect_set_texture(image, texture);
+			gs_effect_set_vec4(color_vec1, &vec1);
+			if (!video->convert_textures[2])
+				gs_effect_set_vec4(color_vec2, &vec2);
+			gs_effect_set_float(width_i, video->conversion_width_i);
+			render_convert_plane(effect, video->convert_textures[1],
+					     video->conversion_techs[1]);
+
+			if (video->convert_textures[2]) {
+				gs_effect_set_texture(image, texture);
+				gs_effect_set_vec4(color_vec2, &vec2);
+				gs_effect_set_float(width_i,
+						    video->conversion_width_i);
+				render_convert_plane(
+					effect, video->convert_textures[2],
+					video->conversion_techs[2]);
+			}
+		}
 	}
-	gs_technique_end(tech);
+
 	gs_enable_blending(true);
 
-	video->textures_converted[cur_texture] = true;
+	video->texture_converted = true;
 
-end:
 	profile_end(render_convert_texture_name);
 }
 
-static void render_nv12(struct obs_core_video *video, gs_texture_t *target,
-		int cur_texture, int prev_texture, const char *tech_name,
-		uint32_t width, uint32_t height)
-{
-	gs_texture_t *texture = video->output_textures[prev_texture];
-
-	gs_effect_t    *effect  = video->conversion_effect;
-	gs_eparam_t    *image   = gs_effect_get_param_by_name(effect, "image");
-	gs_technique_t *tech    = gs_effect_get_technique(effect, tech_name);
-	size_t         passes, i;
-
-	gs_effect_set_texture(image, texture);
-
-	gs_set_render_target(target, NULL);
-	set_render_size(width, height);
-
-	gs_enable_blending(false);
-	passes = gs_technique_begin(tech);
-	for (i = 0; i < passes; i++) {
-		gs_technique_begin_pass(tech, i);
-		gs_draw_sprite(texture, 0, width, height);
-		gs_technique_end_pass(tech);
-	}
-	gs_technique_end(tech);
-	gs_enable_blending(true);
-
-	UNUSED_PARAMETER(cur_texture);
-}
-
-static const char *render_convert_nv12_name = "render_convert_texture_nv12";
-static void render_convert_texture_nv12(struct obs_core_video *video,
-		int cur_texture, int prev_texture)
-{
-	profile_start(render_convert_nv12_name);
-
-	if (!video->textures_output[prev_texture])
-		goto end;
-
-	render_nv12(video, video->convert_textures[cur_texture],
-			cur_texture, prev_texture, "NV12_Y",
-			video->output_width, video->output_height);
-	render_nv12(video, video->convert_uv_textures[cur_texture],
-			cur_texture, prev_texture, "NV12_UV",
-			video->output_width / 2, video->output_height / 2);
-
-	video->textures_converted[cur_texture] = true;
-
-end:
-	profile_end(render_convert_nv12_name);
-}
-
 static const char *stage_output_texture_name = "stage_output_texture";
 static inline void stage_output_texture(struct obs_core_video *video,
-		int cur_texture, int prev_texture)
+					int cur_texture)
 {
 	profile_start(stage_output_texture_name);
 
-	gs_texture_t   *texture;
-	bool        texture_ready;
-	gs_stagesurf_t *copy = video->copy_surfaces[cur_texture];
-
-	if (video->gpu_conversion) {
-		texture = video->convert_textures[prev_texture];
-		texture_ready = video->textures_converted[prev_texture];
-	} else {
-		texture = video->output_textures[prev_texture];
-		texture_ready = video->textures_output[prev_texture];
-	}
-
 	unmap_last_surface(video);
 
-	if (!texture_ready)
-		goto end;
+	if (!video->gpu_conversion) {
+		gs_stagesurf_t *copy = video->copy_surfaces[cur_texture][0];
+		if (copy)
+			gs_stage_texture(copy, video->output_texture);
 
-	gs_stage_texture(copy, texture);
+		video->textures_copied[cur_texture] = true;
+	} else if (video->texture_converted) {
+		for (int i = 0; i < NUM_CHANNELS; i++) {
+			gs_stagesurf_t *copy =
+				video->copy_surfaces[cur_texture][i];
+			if (copy)
+				gs_stage_texture(copy,
+						 video->convert_textures[i]);
+		}
 
-	video->textures_copied[cur_texture] = true;
+		video->textures_copied[cur_texture] = true;
+	}
 
-end:
 	profile_end(stage_output_texture_name);
 }
 
 #ifdef _WIN32
 static inline bool queue_frame(struct obs_core_video *video, bool raw_active,
-		struct obs_vframe_info *vframe_info, int prev_texture)
+			       struct obs_vframe_info *vframe_info)
 {
-	bool duplicate = !video->gpu_encoder_avail_queue.size ||
+	bool duplicate =
+		!video->gpu_encoder_avail_queue.size ||
 		(video->gpu_encoder_queue.size && vframe_info->count > 1);
 
 	if (duplicate) {
 		struct obs_tex_frame *tf = circlebuf_data(
-				&video->gpu_encoder_queue,
-				video->gpu_encoder_queue.size - sizeof(*tf));
+			&video->gpu_encoder_queue,
+			video->gpu_encoder_queue.size - sizeof(*tf));
 
 		/* texture-based encoding is stopping */
 		if (!tf) {
@@ -435,13 +413,13 @@ static inline bool queue_frame(struct obs_core_video *video, bool raw_active,
 	 * reason.  otherwise, it goes to the 'duplicate' case above, which
 	 * will ensure better performance. */
 	if (raw_active || vframe_info->count > 1) {
-		gs_copy_texture(tf.tex, video->convert_textures[prev_texture]);
+		gs_copy_texture(tf.tex, video->convert_textures[0]);
 	} else {
-		gs_texture_t *tex = video->convert_textures[prev_texture];
-		gs_texture_t *tex_uv = video->convert_uv_textures[prev_texture];
+		gs_texture_t *tex = video->convert_textures[0];
+		gs_texture_t *tex_uv = video->convert_textures[1];
 
-		video->convert_textures[prev_texture] = tf.tex;
-		video->convert_uv_textures[prev_texture] = tf.tex_uv;
+		video->convert_textures[0] = tf.tex;
+		video->convert_textures[1] = tf.tex_uv;
 
 		tf.tex = tex;
 		tf.tex_uv = tex_uv;
@@ -463,28 +441,28 @@ finish:
 extern void full_stop(struct obs_encoder *encoder);
 
 static inline void encode_gpu(struct obs_core_video *video, bool raw_active,
-		struct obs_vframe_info *vframe_info, int prev_texture)
+			      struct obs_vframe_info *vframe_info)
 {
-	while (queue_frame(video, raw_active, vframe_info, prev_texture));
+	while (queue_frame(video, raw_active, vframe_info))
+		;
 }
 
 static const char *output_gpu_encoders_name = "output_gpu_encoders";
-static void output_gpu_encoders(struct obs_core_video *video, bool raw_active,
-		int prev_texture)
+static void output_gpu_encoders(struct obs_core_video *video, bool raw_active)
 {
 	profile_start(output_gpu_encoders_name);
 
-	if (!video->textures_converted[prev_texture])
+	if (!video->texture_converted)
 		goto end;
 	if (!video->vframe_info_buffer_gpu.size)
 		goto end;
 
 	struct obs_vframe_info vframe_info;
 	circlebuf_pop_front(&video->vframe_info_buffer_gpu, &vframe_info,
-			sizeof(vframe_info));
+			    sizeof(vframe_info));
 
 	pthread_mutex_lock(&video->gpu_encoder_mutex);
-	encode_gpu(video, raw_active, &vframe_info, prev_texture);
+	encode_gpu(video, raw_active, &vframe_info);
 	pthread_mutex_unlock(&video->gpu_encoder_mutex);
 
 end:
@@ -492,45 +470,36 @@ end:
 }
 #endif
 
-static inline void render_video(struct obs_core_video *video,
-		bool raw_active, const bool gpu_active,
-		int cur_texture, int prev_texture)
+static inline void render_video(struct obs_core_video *video, bool raw_active,
+				const bool gpu_active, int cur_texture)
 {
 	gs_begin_scene();
 
 	gs_enable_depth_test(false);
 	gs_set_cull_mode(GS_NEITHER);
 
-	render_main_texture(video, cur_texture);
+	render_main_texture(video);
 
 	if (raw_active || gpu_active) {
-		render_output_texture(video, cur_texture, prev_texture);
+		gs_texture_t *texture = render_output_texture(video);
+
+#ifdef _WIN32
+		if (gpu_active)
+			gs_flush();
+#endif
+
+		if (video->gpu_conversion)
+			render_convert_texture(video, texture);
 
 #ifdef _WIN32
 		if (gpu_active) {
 			gs_flush();
+			output_gpu_encoders(video, raw_active);
 		}
 #endif
-	}
 
-	if (raw_active || gpu_active) {
-		if (video->gpu_conversion) {
-			if (video->using_nv12_tex)
-				render_convert_texture_nv12(video,
-						cur_texture, prev_texture);
-			else
-				render_convert_texture(video,
-						cur_texture, prev_texture);
-		}
-
-#ifdef _WIN32
-		if (gpu_active) {
-			gs_flush();
-			output_gpu_encoders(video, raw_active, prev_texture);
-		}
-#endif
 		if (raw_active)
-			stage_output_texture(video, cur_texture, prev_texture);
+			stage_output_texture(video, cur_texture);
 	}
 
 	gs_set_render_target(NULL, NULL);
@@ -540,149 +509,158 @@ static inline void render_video(struct obs_core_video *video,
 }
 
 static inline bool download_frame(struct obs_core_video *video,
-		int prev_texture, struct video_data *frame)
+				  int prev_texture, struct video_data *frame)
 {
-	gs_stagesurf_t *surface = video->copy_surfaces[prev_texture];
-
 	if (!video->textures_copied[prev_texture])
 		return false;
 
-	if (!gs_stagesurface_map(surface, &frame->data[0], &frame->linesize[0]))
-		return false;
+	for (int channel = 0; channel < NUM_CHANNELS; ++channel) {
+		gs_stagesurf_t *surface =
+			video->copy_surfaces[prev_texture][channel];
+		if (surface) {
+			if (!gs_stagesurface_map(surface, &frame->data[channel],
+						 &frame->linesize[channel]))
+				return false;
 
-	video->mapped_surface = surface;
+			video->mapped_surfaces[channel] = surface;
+		}
+	}
 	return true;
 }
 
-static inline uint32_t calc_linesize(uint32_t pos, uint32_t linesize)
+static const uint8_t *set_gpu_converted_plane(uint32_t width, uint32_t height,
+					      uint32_t linesize_input,
+					      uint32_t linesize_output,
+					      const uint8_t *in, uint8_t *out)
 {
-	uint32_t size = pos % linesize;
-	return size ? size : linesize;
-}
-
-static void copy_dealign(
-		uint8_t *dst, uint32_t dst_pos, uint32_t dst_linesize,
-		const uint8_t *src, uint32_t src_pos, uint32_t src_linesize,
-		uint32_t remaining)
-{
-	while (remaining) {
-		uint32_t src_remainder = src_pos % src_linesize;
-		uint32_t dst_offset = dst_linesize - src_remainder;
-		uint32_t src_offset = src_linesize - src_remainder;
-
-		if (remaining < dst_offset) {
-			memcpy(dst + dst_pos, src + src_pos, remaining);
-			src_pos += remaining;
-			dst_pos += remaining;
-			remaining = 0;
-		} else {
-			memcpy(dst + dst_pos, src + src_pos, dst_offset);
-			src_pos += src_offset;
-			dst_pos += dst_offset;
-			remaining -= dst_offset;
+	if ((width == linesize_input) && (width == linesize_output)) {
+		size_t total = width * height;
+		memcpy(out, in, total);
+		in += total;
+	} else {
+		for (size_t y = 0; y < height; y++) {
+			memcpy(out, in, width);
+			out += linesize_output;
+			in += linesize_input;
 		}
 	}
-}
 
-static inline uint32_t make_aligned_linesize_offset(uint32_t offset,
-		uint32_t dst_linesize, uint32_t src_linesize)
-{
-	uint32_t remainder = offset % dst_linesize;
-	return (offset / dst_linesize) * src_linesize + remainder;
-}
-
-static void fix_gpu_converted_alignment(struct obs_core_video *video,
-		struct video_frame *output, const struct video_data *input)
-{
-	uint32_t src_linesize = input->linesize[0];
-	uint32_t dst_linesize = output->linesize[0] * 4;
-	uint32_t src_pos      = 0;
-
-	for (size_t i = 0; i < 3; i++) {
-		if (video->plane_linewidth[i] == 0)
-			break;
-
-		src_pos = make_aligned_linesize_offset(video->plane_offsets[i],
-				dst_linesize, src_linesize);
-
-		copy_dealign(output->data[i], 0, dst_linesize,
-				input->data[0], src_pos, src_linesize,
-				video->plane_sizes[i]);
-	}
+	return in;
 }
 
 static void set_gpu_converted_data(struct obs_core_video *video,
-		struct video_frame *output, const struct video_data *input,
-		const struct video_output_info *info)
+				   struct video_frame *output,
+				   const struct video_data *input,
+				   const struct video_output_info *info)
 {
-	if (input->linesize[0] == video->output_width*4) {
-		struct video_frame frame;
+	if (video->using_nv12_tex) {
+		const uint32_t width = info->width;
+		const uint32_t height = info->height;
 
-		for (size_t i = 0; i < 3; i++) {
-			if (video->plane_linewidth[i] == 0)
-				break;
-
-			frame.linesize[i] = video->plane_linewidth[i];
-			frame.data[i] =
-				input->data[0] + video->plane_offsets[i];
-		}
-
-		video_frame_copy(output, &frame, info->format, info->height);
-
-	} else if (video->using_nv12_tex) {
-		size_t width = info->width;
-		size_t height = info->height;
-		size_t height_d2 = height / 2;
-		uint8_t *out_y = output->data[0];
-		uint8_t *out_uv = output->data[1];
-		uint8_t *in = input->data[0];
-
-		for (size_t y = 0; y < height; y++) {
-			memcpy(out_y, in, width);
-			out_y += output->linesize[0];
-			in += input->linesize[0];
-		}
-		for (size_t y = 0; y < height_d2; y++) {
-			memcpy(out_uv, in, width);
-			out_uv += output->linesize[0];
-			in += input->linesize[0];
-		}
+		const uint8_t *const in_uv = set_gpu_converted_plane(
+			width, height, input->linesize[0], output->linesize[0],
+			input->data[0], output->data[0]);
 
+		const uint32_t height_d2 = height / 2;
+		set_gpu_converted_plane(width, height_d2, input->linesize[0],
+					output->linesize[1], in_uv,
+					output->data[1]);
 	} else {
-		fix_gpu_converted_alignment(video, output, input);
+		switch (info->format) {
+		case VIDEO_FORMAT_I420: {
+			const uint32_t width = info->width;
+			const uint32_t height = info->height;
+
+			set_gpu_converted_plane(width, height,
+						input->linesize[0],
+						output->linesize[0],
+						input->data[0],
+						output->data[0]);
+
+			const uint32_t width_d2 = width / 2;
+			const uint32_t height_d2 = height / 2;
+
+			set_gpu_converted_plane(width_d2, height_d2,
+						input->linesize[1],
+						output->linesize[1],
+						input->data[1],
+						output->data[1]);
+
+			set_gpu_converted_plane(width_d2, height_d2,
+						input->linesize[2],
+						output->linesize[2],
+						input->data[2],
+						output->data[2]);
+
+			break;
+		}
+		case VIDEO_FORMAT_NV12: {
+			const uint32_t width = info->width;
+			const uint32_t height = info->height;
+
+			set_gpu_converted_plane(width, height,
+						input->linesize[0],
+						output->linesize[0],
+						input->data[0],
+						output->data[0]);
+
+			const uint32_t height_d2 = height / 2;
+			set_gpu_converted_plane(width, height_d2,
+						input->linesize[1],
+						output->linesize[1],
+						input->data[1],
+						output->data[1]);
+
+			break;
+		}
+		case VIDEO_FORMAT_I444: {
+			const uint32_t width = info->width;
+			const uint32_t height = info->height;
+
+			set_gpu_converted_plane(width, height,
+						input->linesize[0],
+						output->linesize[0],
+						input->data[0],
+						output->data[0]);
+
+			set_gpu_converted_plane(width, height,
+						input->linesize[1],
+						output->linesize[1],
+						input->data[1],
+						output->data[1]);
+
+			set_gpu_converted_plane(width, height,
+						input->linesize[2],
+						output->linesize[2],
+						input->data[2],
+						output->data[2]);
+
+			break;
+		}
+
+		case VIDEO_FORMAT_NONE:
+		case VIDEO_FORMAT_YVYU:
+		case VIDEO_FORMAT_YUY2:
+		case VIDEO_FORMAT_UYVY:
+		case VIDEO_FORMAT_RGBA:
+		case VIDEO_FORMAT_BGRA:
+		case VIDEO_FORMAT_BGRX:
+		case VIDEO_FORMAT_Y800:
+		case VIDEO_FORMAT_BGR3:
+		case VIDEO_FORMAT_I422:
+		case VIDEO_FORMAT_I40A:
+		case VIDEO_FORMAT_I42A:
+		case VIDEO_FORMAT_YUVA:
+		case VIDEO_FORMAT_AYUV:
+			/* unimplemented */
+			;
+		}
 	}
 }
 
-static void convert_frame(
-		struct video_frame *output, const struct video_data *input,
-		const struct video_output_info *info)
-{
-	if (info->format == VIDEO_FORMAT_I420) {
-		compress_uyvx_to_i420(
-				input->data[0], input->linesize[0],
-				0, info->height,
-				output->data, output->linesize);
-
-	} else if (info->format == VIDEO_FORMAT_NV12) {
-		compress_uyvx_to_nv12(
-				input->data[0], input->linesize[0],
-				0, info->height,
-				output->data, output->linesize);
-
-	} else if (info->format == VIDEO_FORMAT_I444) {
-		convert_uyvx_to_i444(
-				input->data[0], input->linesize[0],
-				0, info->height,
-				output->data, output->linesize);
-
-	} else {
-		blog(LOG_ERROR, "convert_frame: unsupported texture format");
-	}
-}
-
-static inline void copy_rgbx_frame(
-		struct video_frame *output, const struct video_data *input,
-		const struct video_output_info *info)
+static inline void copy_rgbx_frame(struct video_frame *output,
+				   const struct video_data *input,
+				   const struct video_output_info *info)
 {
 	uint8_t *in_ptr = input->data[0];
 	uint8_t *out_ptr = output->data[0];
@@ -700,7 +678,7 @@ static inline void copy_rgbx_frame(
 }
 
 static inline void output_video_data(struct obs_core_video *video,
-		struct video_data *input_frame, int count)
+				     struct video_data *input_frame, int count)
 {
 	const struct video_output_info *info;
 	struct video_frame output_frame;
@@ -709,14 +687,11 @@ static inline void output_video_data(struct obs_core_video *video,
 	info = video_output_get_info(video->video);
 
 	locked = video_output_lock_frame(video->video, &output_frame, count,
-			input_frame->timestamp);
+					 input_frame->timestamp);
 	if (locked) {
 		if (video->gpu_conversion) {
 			set_gpu_converted_data(video, &output_frame,
-					input_frame, info);
-
-		} else if (format_is_yuv(info->format)) {
-			convert_frame(&output_frame, input_frame, info);
+					       input_frame, info);
 		} else {
 			copy_rgbx_frame(&output_frame, input_frame, info);
 		}
@@ -725,9 +700,9 @@ static inline void output_video_data(struct obs_core_video *video,
 	}
 }
 
-static inline void video_sleep(struct obs_core_video *video,
-		bool raw_active, const bool gpu_active,
-		uint64_t *p_time, uint64_t interval_ns)
+static inline void video_sleep(struct obs_core_video *video, bool raw_active,
+			       const bool gpu_active, uint64_t *p_time,
+			       uint64_t interval_ns)
 {
 	struct obs_vframe_info vframe_info;
 	uint64_t cur_time = *p_time;
@@ -750,10 +725,10 @@ static inline void video_sleep(struct obs_core_video *video,
 
 	if (raw_active)
 		circlebuf_push_back(&video->vframe_info_buffer, &vframe_info,
-				sizeof(vframe_info));
+				    sizeof(vframe_info));
 	if (gpu_active)
 		circlebuf_push_back(&video->vframe_info_buffer_gpu,
-				&vframe_info, sizeof(vframe_info));
+				    &vframe_info, sizeof(vframe_info));
 }
 
 static const char *output_frame_gs_context_name = "gs_context(video->graphics)";
@@ -764,8 +739,9 @@ static const char *output_frame_output_video_data_name = "output_video_data";
 static inline void output_frame(bool raw_active, const bool gpu_active)
 {
 	struct obs_core_video *video = &obs->video;
-	int cur_texture  = video->cur_texture;
-	int prev_texture = cur_texture == 0 ? NUM_TEXTURES-1 : cur_texture-1;
+	int cur_texture = video->cur_texture;
+	int prev_texture = cur_texture == 0 ? NUM_TEXTURES - 1
+					    : cur_texture - 1;
 	struct video_data frame;
 	bool frame_ready = 0;
 
@@ -776,8 +752,8 @@ static inline void output_frame(bool raw_active, const bool gpu_active)
 
 	profile_start(output_frame_render_video_name);
 	GS_DEBUG_MARKER_BEGIN(GS_DEBUG_COLOR_RENDER_VIDEO,
-			output_frame_render_video_name);
-	render_video(video, raw_active, gpu_active, cur_texture, prev_texture);
+			      output_frame_render_video_name);
+	render_video(video, raw_active, gpu_active, cur_texture);
 	GS_DEBUG_MARKER_END();
 	profile_end(output_frame_render_video_name);
 
@@ -797,7 +773,7 @@ static inline void output_frame(bool raw_active, const bool gpu_active)
 	if (raw_active && frame_ready) {
 		struct obs_vframe_info vframe_info;
 		circlebuf_pop_front(&video->vframe_info_buffer, &vframe_info,
-				sizeof(vframe_info));
+				    sizeof(vframe_info));
 
 		frame.timestamp = vframe_info.timestamp;
 		profile_start(output_frame_output_video_data_name);
@@ -814,9 +790,8 @@ static inline void output_frame(bool raw_active, const bool gpu_active)
 static void clear_base_frame_data(void)
 {
 	struct obs_core_video *video = &obs->video;
-	memset(video->textures_rendered, 0, sizeof(video->textures_rendered));
-	memset(video->textures_output, 0, sizeof(video->textures_output));
-	memset(video->textures_converted, 0, sizeof(video->textures_converted));
+	video->texture_rendered = false;
+	video->texture_converted = false;
 	circlebuf_free(&video->vframe_info_buffer);
 	video->cur_texture = 0;
 }
@@ -853,12 +828,13 @@ void *obs_graphics_thread(void *param)
 	bool was_active = false;
 
 	obs->video.video_time = os_gettime_ns();
+	obs->video.video_frame_interval_ns = interval;
 
 	os_set_thread_name("libobs: graphics thread");
 
-	const char *video_thread_name =
-		profile_store_name(obs_get_profiler_name_store(),
-			"obs_graphics_thread(%g"NBSP"ms)", interval / 1000000.);
+	const char *video_thread_name = profile_store_name(
+		obs_get_profiler_name_store(),
+		"obs_graphics_thread(%g" NBSP "ms)", interval / 1000000.);
 	profile_register_root(video_thread_name, interval);
 
 	srand((unsigned int)time(NULL));
@@ -909,17 +885,19 @@ void *obs_graphics_thread(void *param)
 		profile_reenable_thread();
 
 		video_sleep(&obs->video, raw_active, gpu_active,
-				&obs->video.video_time, interval);
+			    &obs->video.video_time, interval);
 
 		frame_time_total_ns += frame_time_ns;
 		fps_total_ns += (obs->video.video_time - last_time);
 		fps_total_frames++;
 
 		if (fps_total_ns >= 1000000000ULL) {
-			obs->video.video_fps = (double)fps_total_frames /
+			obs->video.video_fps =
+				(double)fps_total_frames /
 				((double)fps_total_ns / 1000000000.0);
 			obs->video.video_avg_frame_time_ns =
-				frame_time_total_ns / (uint64_t)fps_total_frames;
+				frame_time_total_ns /
+				(uint64_t)fps_total_frames;
 
 			frame_time_total_ns = 0;
 			fps_total_ns = 0;
