@@ -22,13 +22,13 @@ static const char *rtmp_common_getname(void *unused)
 
 static json_t *open_services_file(void);
 static inline json_t *find_service(json_t *root, const char *name,
-		const char **p_new_name);
+				   const char **p_new_name);
 static inline const char *get_string_val(json_t *service, const char *key);
 
 extern void twitch_ingests_refresh(int seconds);
 
 static void ensure_valid_url(struct rtmp_common *service, json_t *json,
-		obs_data_t *settings)
+			     obs_data_t *settings)
 {
 	json_t *servers = json_object_get(json, "servers");
 	const char *top_url = NULL;
@@ -70,9 +70,9 @@ static void rtmp_common_update(void *data, obs_data_t *settings)
 	bfree(service->key);
 
 	service->service = bstrdup(obs_data_get_string(settings, "service"));
-	service->server  = bstrdup(obs_data_get_string(settings, "server"));
-	service->key     = bstrdup(obs_data_get_string(settings, "key"));
-	service->output  = NULL;
+	service->server = bstrdup(obs_data_get_string(settings, "server"));
+	service->key = bstrdup(obs_data_get_string(settings, "key"));
+	service->output = NULL;
 
 	json_t *root = open_services_file();
 	if (root) {
@@ -86,7 +86,7 @@ static void rtmp_common_update(void *data, obs_data_t *settings)
 
 		if (serv) {
 			json_t *rec = json_object_get(serv, "recommended");
-			if (rec && json_is_object(rec)) {
+			if (json_is_object(rec)) {
 				const char *out = get_string_val(rec, "output");
 				if (out)
 					service->output = bstrdup(out);
@@ -149,7 +149,7 @@ static inline bool get_bool_val(json_t *service, const char *key)
 }
 
 static void add_service(obs_property_t *list, json_t *service, bool show_all,
-		const char *cur_service)
+			const char *cur_service)
 {
 	json_t *servers;
 	const char *name;
@@ -157,14 +157,14 @@ static void add_service(obs_property_t *list, json_t *service, bool show_all,
 
 	if (!json_is_object(service)) {
 		blog(LOG_WARNING, "rtmp-common.c: [add_service] service "
-		                  "is not an object");
+				  "is not an object");
 		return;
 	}
 
 	name = get_string_val(service, "name");
 	if (!name) {
 		blog(LOG_WARNING, "rtmp-common.c: [add_service] service "
-		                  "has no name");
+				  "has no name");
 		return;
 	}
 
@@ -175,8 +175,10 @@ static void add_service(obs_property_t *list, json_t *service, bool show_all,
 
 	servers = json_object_get(service, "servers");
 	if (!servers || !json_is_array(servers)) {
-		blog(LOG_WARNING, "rtmp-common.c: [add_service] service "
-		                  "'%s' has no servers", name);
+		blog(LOG_WARNING,
+		     "rtmp-common.c: [add_service] service "
+		     "'%s' has no servers",
+		     name);
 		return;
 	}
 
@@ -184,14 +186,14 @@ static void add_service(obs_property_t *list, json_t *service, bool show_all,
 }
 
 static void add_services(obs_property_t *list, json_t *root, bool show_all,
-		const char *cur_service)
+			 const char *cur_service)
 {
 	json_t *service;
 	size_t index;
 
 	if (!json_is_array(root)) {
 		blog(LOG_WARNING, "rtmp-common.c: [add_services] JSON file "
-		                  "root is not an array");
+				  "root is not an array");
 		return;
 	}
 
@@ -202,18 +204,18 @@ static void add_services(obs_property_t *list, json_t *root, bool show_all,
 	service = find_service(root, cur_service, NULL);
 	if (!service && cur_service && *cur_service) {
 		obs_property_list_insert_string(list, 0, cur_service,
-				cur_service);
+						cur_service);
 		obs_property_list_item_disable(list, 0, true);
 	}
 }
 
 static json_t *open_json_file(const char *file)
 {
-	char         *file_data = os_quick_read_utf8_file(file);
+	char *file_data = os_quick_read_utf8_file(file);
 	json_error_t error;
-	json_t       *root;
-	json_t       *list;
-	int          format_ver;
+	json_t *root;
+	json_t *list;
+	int format_ver;
 
 	if (!file_data)
 		return NULL;
@@ -222,18 +224,20 @@ static json_t *open_json_file(const char *file)
 	bfree(file_data);
 
 	if (!root) {
-		blog(LOG_WARNING, "rtmp-common.c: [open_json_file] "
-		                  "Error reading JSON file (%d): %s",
-		                  error.line, error.text);
+		blog(LOG_WARNING,
+		     "rtmp-common.c: [open_json_file] "
+		     "Error reading JSON file (%d): %s",
+		     error.line, error.text);
 		return NULL;
 	}
 
 	format_ver = get_int_val(root, "format_version");
 
 	if (format_ver != RTMP_SERVICES_FORMAT_VERSION) {
-		blog(LOG_DEBUG, "rtmp-common.c: [open_json_file] "
-		                "Wrong format version (%d), expected %d",
-		                format_ver, RTMP_SERVICES_FORMAT_VERSION);
+		blog(LOG_DEBUG,
+		     "rtmp-common.c: [open_json_file] "
+		     "Wrong format version (%d), expected %d",
+		     format_ver, RTMP_SERVICES_FORMAT_VERSION);
 		json_decref(root);
 		return NULL;
 	}
@@ -245,7 +249,7 @@ static json_t *open_json_file(const char *file)
 
 	if (!list) {
 		blog(LOG_WARNING, "rtmp-common.c: [open_json_file] "
-		                  "No services list");
+				  "No services list");
 		return NULL;
 	}
 
@@ -275,7 +279,7 @@ static json_t *open_services_file(void)
 }
 
 static void build_service_list(obs_property_t *list, json_t *root,
-		bool show_all, const char *cur_service)
+			       bool show_all, const char *cur_service)
 {
 	obs_property_list_clear(list);
 	add_services(list, root, show_all, cur_service);
@@ -293,7 +297,7 @@ static bool fill_twitch_servers_locked(obs_property_t *servers_prop)
 	size_t count = twitch_ingest_count();
 
 	obs_property_list_add_string(servers_prop,
-			obs_module_text("Server.Auto"), "auto");
+				     obs_module_text("Server.Auto"), "auto");
 
 	if (count <= 1)
 		return false;
@@ -318,7 +322,7 @@ static inline bool fill_twitch_servers(obs_property_t *servers_prop)
 }
 
 static void fill_servers(obs_property_t *servers_prop, json_t *service,
-		const char *name)
+			 const char *name)
 {
 	json_t *servers, *server;
 	size_t index;
@@ -328,15 +332,16 @@ static void fill_servers(obs_property_t *servers_prop, json_t *service,
 	servers = json_object_get(service, "servers");
 
 	if (!json_is_array(servers)) {
-		blog(LOG_WARNING, "rtmp-common.c: [fill_servers] "
-		                  "Servers for service '%s' not a valid object",
-		                  name);
+		blog(LOG_WARNING,
+		     "rtmp-common.c: [fill_servers] "
+		     "Servers for service '%s' not a valid object",
+		     name);
 		return;
 	}
 
 	if (strcmp(name, "Mixer.com - FTL") == 0) {
-		obs_property_list_add_string(servers_prop,
-				obs_module_text("Server.Auto"), "auto");
+		obs_property_list_add_string(
+			servers_prop, obs_module_text("Server.Auto"), "auto");
 	}
 	if (strcmp(name, "Twitch") == 0) {
 		if (fill_twitch_servers(servers_prop))
@@ -345,7 +350,7 @@ static void fill_servers(obs_property_t *servers_prop, json_t *service,
 
 	json_array_foreach (servers, index, server) {
 		const char *server_name = get_string_val(server, "name");
-		const char *url         = get_string_val(server, "url");
+		const char *url = get_string_val(server, "url");
 
 		if (!server_name || !url)
 			continue;
@@ -355,12 +360,13 @@ static void fill_servers(obs_property_t *servers_prop, json_t *service,
 }
 
 static inline json_t *find_service(json_t *root, const char *name,
-		const char **p_new_name)
+				   const char **p_new_name)
 {
 	size_t index;
 	json_t *service;
 
-	if (p_new_name) *p_new_name = NULL;
+	if (p_new_name)
+		*p_new_name = NULL;
 
 	json_array_foreach (root, index, service) {
 		const char *cur_name = get_string_val(service, "name");
@@ -376,7 +382,8 @@ static inline json_t *find_service(json_t *root, const char *name,
 		json_array_foreach (alt_names, alt_name_idx, alt_name_obj) {
 			const char *alt_name = json_string_value(alt_name_obj);
 			if (alt_name && strcmp(name, alt_name) == 0) {
-				if (p_new_name) *p_new_name = cur_name;
+				if (p_new_name)
+					*p_new_name = cur_name;
 				return service;
 			}
 		}
@@ -386,10 +393,10 @@ static inline json_t *find_service(json_t *root, const char *name,
 }
 
 static bool service_selected(obs_properties_t *props, obs_property_t *p,
-		obs_data_t *settings)
+			     obs_data_t *settings)
 {
 	const char *name = obs_data_get_string(settings, "service");
-	json_t *root     = obs_properties_get_param(props);
+	json_t *root = obs_properties_get_param(props);
 	json_t *service;
 	const char *new_name;
 
@@ -418,8 +425,8 @@ static bool service_selected(obs_properties_t *props, obs_property_t *p,
 	return true;
 }
 
-static bool show_all_services_toggled(obs_properties_t *ppts,
-		obs_property_t *p, obs_data_t *settings)
+static bool show_all_services_toggled(obs_properties_t *ppts, obs_property_t *p,
+				      obs_data_t *settings)
 {
 	const char *cur_service = obs_data_get_string(settings, "service");
 	bool show_all = obs_data_get_bool(settings, "show_all");
@@ -429,7 +436,7 @@ static bool show_all_services_toggled(obs_properties_t *ppts,
 		return false;
 
 	build_service_list(obs_properties_get(ppts, "service"), root, show_all,
-			cur_service);
+			   cur_service);
 
 	UNUSED_PARAMETER(p);
 	return true;
@@ -440,37 +447,37 @@ static obs_properties_t *rtmp_common_properties(void *unused)
 	UNUSED_PARAMETER(unused);
 
 	obs_properties_t *ppts = obs_properties_create();
-	obs_property_t   *p;
-	json_t           *root;
+	obs_property_t *p;
+	json_t *root;
 
 	root = open_services_file();
 	if (root)
 		obs_properties_set_param(ppts, root, properties_data_destroy);
 
-	p = obs_properties_add_list(ppts, "service",
-			obs_module_text("Service"),
-			OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_STRING);
+	p = obs_properties_add_list(ppts, "service", obs_module_text("Service"),
+				    OBS_COMBO_TYPE_LIST,
+				    OBS_COMBO_FORMAT_STRING);
 
 	obs_property_set_modified_callback(p, service_selected);
 
 	p = obs_properties_add_bool(ppts, "show_all",
-			obs_module_text("ShowAll"));
+				    obs_module_text("ShowAll"));
 
 	obs_property_set_modified_callback(p, show_all_services_toggled);
 
 	obs_properties_add_list(ppts, "server", obs_module_text("Server"),
-			OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_STRING);
+				OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_STRING);
 
 	obs_properties_add_text(ppts, "key", obs_module_text("StreamKey"),
-			OBS_TEXT_PASSWORD);
+				OBS_TEXT_PASSWORD);
 	return ppts;
 }
 
 static void apply_video_encoder_settings(obs_data_t *settings,
-		json_t *recommended)
+					 json_t *recommended)
 {
 	json_t *item = json_object_get(recommended, "keyint");
-	if (item && json_is_integer(item)) {
+	if (json_is_integer(item)) {
 		int keyint = (int)json_integer_value(item);
 		obs_data_set_int(settings, "keyint_sec", keyint);
 	}
@@ -478,13 +485,13 @@ static void apply_video_encoder_settings(obs_data_t *settings,
 	obs_data_set_string(settings, "rate_control", "CBR");
 
 	item = json_object_get(recommended, "profile");
-	if (item && json_is_string(item)) {
+	if (json_is_string(item)) {
 		const char *profile = json_string_value(item);
 		obs_data_set_string(settings, "profile", profile);
 	}
 
 	item = json_object_get(recommended, "max video bitrate");
-	if (item && json_is_integer(item)) {
+	if (json_is_integer(item)) {
 		int max_bitrate = (int)json_integer_value(item);
 		if (obs_data_get_int(settings, "bitrate") > max_bitrate) {
 			obs_data_set_int(settings, "bitrate", max_bitrate);
@@ -493,11 +500,11 @@ static void apply_video_encoder_settings(obs_data_t *settings,
 	}
 
 	item = json_object_get(recommended, "bframes");
-	if (item && json_is_integer(item))
+	if (json_is_integer(item))
 		obs_data_set_int(settings, "bf", 0);
 
 	item = json_object_get(recommended, "x264opts");
-	if (item && json_is_string(item)) {
+	if (json_is_string(item)) {
 		const char *x264_settings = json_string_value(item);
 		const char *cur_settings =
 			obs_data_get_string(settings, "x264opts");
@@ -514,10 +521,10 @@ static void apply_video_encoder_settings(obs_data_t *settings,
 }
 
 static void apply_audio_encoder_settings(obs_data_t *settings,
-		json_t *recommended)
+					 json_t *recommended)
 {
 	json_t *item = json_object_get(recommended, "max audio bitrate");
-	if (item && json_is_integer(item)) {
+	if (json_is_integer(item)) {
 		int max_bitrate = (int)json_integer_value(item);
 		if (obs_data_get_int(settings, "bitrate") > max_bitrate)
 			obs_data_set_int(settings, "bitrate", max_bitrate);
@@ -525,16 +532,18 @@ static void apply_audio_encoder_settings(obs_data_t *settings,
 }
 
 static void initialize_output(struct rtmp_common *service, json_t *root,
-		obs_data_t *video_settings, obs_data_t *audio_settings)
+			      obs_data_t *video_settings,
+			      obs_data_t *audio_settings)
 {
-	json_t        *json_service = find_service(root, service->service, NULL);
-	json_t        *recommended;
+	json_t *json_service = find_service(root, service->service, NULL);
+	json_t *recommended;
 
 	if (!json_service) {
 		if (service->service && *service->service)
-			blog(LOG_WARNING, "rtmp-common.c: [initialize_output] "
-					  "Could not find service '%s'",
-					  service->service);
+			blog(LOG_WARNING,
+			     "rtmp-common.c: [initialize_output] "
+			     "Could not find service '%s'",
+			     service->service);
 		return;
 	}
 
@@ -548,15 +557,15 @@ static void initialize_output(struct rtmp_common *service, json_t *root,
 		apply_audio_encoder_settings(audio_settings, recommended);
 }
 
-static void rtmp_common_apply_settings(void *data,
-		obs_data_t *video_settings, obs_data_t *audio_settings)
+static void rtmp_common_apply_settings(void *data, obs_data_t *video_settings,
+				       obs_data_t *audio_settings)
 {
 	struct rtmp_common *service = data;
-	json_t             *root = open_services_file();
+	json_t *root = open_services_file();
 
 	if (root) {
 		initialize_output(service, root, video_settings,
-				audio_settings);
+				  audio_settings);
 		json_decref(root);
 	}
 }
@@ -595,14 +604,14 @@ static const char *rtmp_common_key(void *data)
 }
 
 struct obs_service_info rtmp_common_service = {
-	.id             = "rtmp_common",
-	.get_name       = rtmp_common_getname,
-	.create         = rtmp_common_create,
-	.destroy        = rtmp_common_destroy,
-	.update         = rtmp_common_update,
+	.id = "rtmp_common",
+	.get_name = rtmp_common_getname,
+	.create = rtmp_common_create,
+	.destroy = rtmp_common_destroy,
+	.update = rtmp_common_update,
 	.get_properties = rtmp_common_properties,
-	.get_url        = rtmp_common_url,
-	.get_key        = rtmp_common_key,
+	.get_url = rtmp_common_url,
+	.get_key = rtmp_common_key,
 	.apply_encoder_settings = rtmp_common_apply_settings,
 	.get_output_type = rtmp_common_get_output_type,
 };
